function Res = FilterApply(Img,FilterModel)
T = FilterModel.T;
binSize = FilterModel.gammaIn;
downRatio = FilterModel.downRatio;
padsize = ceil(FilterModel.gammaOut * 2 + T);
Is = vl_imsmooth(Img, 0.5);
[F, D] =  vl_dsift(single(Is), 'size', binSize, 'Norm', 'FloatDescriptors', 'Step', downRatio);
D = bsxfun(@times, D, F(3,:) ./ (F(3,:)+0.05));

%% reorgernize output D into dense feature map
minXY = min(F,[],2);
maxXY = max(F,[],2);

nf = (maxXY(1) - minXY(1))/downRatio + 1;
mf = (maxXY(2) - minXY(2))/downRatio + 1;

pm = mf + 2 * padsize;
pn = nf + 2 * padsize;

[X Y] = meshgrid(-(pn/2):(pn/2-1),-(pm/2):(pm/2-1));
Z = complex(Y,X);
VoteKernel = exp(-abs(Z).^2/FilterModel.gammaOut^2 / 2);
VoteKernel = VoteKernel /sum(VoteKernel(:));
ftVoteKernel = fft2(fftshift(VoteKernel));

D  = bsxfun(@minus, D', FilterModel.mapping.mean) * FilterModel.mapping.M;
label = soft_kmeans(FilterModel.codes', D, 5, FilterModel.soft_sigma);
%% assign voting coefficients for each pixel
D(:,end+1) = 1;
VC = label * FilterModel.weights.';

Tout = FilterModel.T;

%% voting
Res = zeros(pm,pn);
Q = zeros(mf,nf);
cnt = 1;
for j = Tout:(-1):1,
    for k = 1:size(D,2),
        Q(:) = Q(:) + D(:,k) .* VC(:,cnt);
        cnt = cnt + 1;
    end;
    Res(padsize+1:padsize+mf, padsize+1:padsize+nf) = Res(padsize+1:padsize+mf, padsize+1:padsize+nf) + Q;
    Q(:) = 0;
    if (j > 1)
        Res = complexDerivConj(double(Res));
    end
end;

Res = unPad(ifft2(fft2(Res) .* ftVoteKernel),[mf,nf]) + FilterModel.bias;

Res = real(Res);
res = imresize(Res, [maxXY(2) - minXY(2)+1, maxXY(1) - minXY(1)+1]);
Res = zeros(size(Img,1), size(Img,2));
Res(minXY(2):maxXY(2), minXY(1):maxXY(1)) = res;

end

% 
function re = complexDerivConj(I)
    [x,y] = gradient(I);
    re = 2 * (x - y * 1i);
end

function re = complexDeriv(I)
    [x,y] = gradient(I);
    re = 2 * (x + y * 1i);
end
