%%
baseFolder = 'TestData/20120710_EDF_hsp70_shr3v1_MOe6i6/';

Folders = {'not_TG_ctrl/','not_TG_MO/','TG_ctrl/','TG_MO/'};

outputFolder = 'OutputData/20120710_EDF_hsp70_shr3v1_MOe6i6/';
mkdir(outputFolder);
load('Model.mat');

T = 0.5; % a threshold for visulizing detection
bbr = 10;
elSize = 0.52;  % one pixel is 0.52um after downsampling

%% detection
for iif = 1:numel(Folders)
    folder = [baseFolder Folders{iif}];
    outFolder = [outputFolder Folders{iif}];
    mkdir(outFolder);
    
    files = dir([folder, '*.tif']);
    Record = [];
    for i = 1:numel(files)
        fileName = files(i).name;
        I = imread([folder, fileName]);
      
        img = double(I);
        down = imresize(img,0.5,'bilinear');
        mm = mean(down(:));
        img = down / mm;
        
        stdIntensity = std(img(:));
        img = 1 + (img - 1) * (0.8 / stdIntensity);% normalize image into mean = 1 std = 0.8
        
        mask = makeMask(img);   % segment the interested region
        PP = real(FilterApply(img,FilterModel)); % run the detection filter
        
        %% extract local maxima
        dt = [];
        bw = imregionalmax(PP,26);
        bw = bw & (mask);
        STATS = regionprops(bw, 'Centroid');
        for j = 1:numel(STATS)
            cc = round(STATS(j).Centroid);
            cc = cc([2,1]);
            cc = max(1, cc);
            cc = min(size(bw), cc);
            v = PP(cc(1),cc(2));
            dt = [dt; [cc(2) - bbr, cc(1) - bbr, cc(2) + bbr, cc(1) + bbr, v]];
        end
        % thresholding: remove the points will be 0 in soft weighting
        dt = dt(dt(:,5) > T,:); 
        pick = nms(dt,0.25);
        dt = dt(pick,:);
        dt = clipboxes(img, dt);
        Name{i} = fileName(1:end-4);
        Record{i} = dt;
        
        % visualization
        dt(:,5) = min(max( (dt(:,5) - T) / (1-T), 0),1);    % soft weighting at t = 0.5
        
        figure(1);
        imagesc(img);colormap gray; axis equal off;truesize
        export_fig([outFolder,  fileName(1:end-4)], '-jpg');
        PP = PP.*(PP>0);
        PP(1:11) = 0:0.1:1; 
        imagesc(PP);shg;colormap jet; axis equal off;truesize;
        pause(0.05);
        
        export_fig([outFolder,  fileName(1:end-4) '_det'], '-jpg');
        
        showboxes(img, [dt], [outFolder,  fileName(1:end-4) '_bb']);shg;
        pause(0.1);
    end
    save([outFolder 'Record.mat'], 'Record', 'Name');
end




